#
# spec file for package python-bugzilla
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-bugzilla
Version:        2.3.0
Release:        lp152.2.7.1
Summary:        Python library for Bugzilla
License:        GPL-2.0-or-later
Group:          Development/Libraries/Python
URL:            https://github.com/python-bugzilla/python-bugzilla
Source:         https://files.pythonhosted.org/packages/source/p/python-bugzilla/python-bugzilla-%{version}.tar.gz
Patch0:         106-basic-auth.diff
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests
Requires(post): update-alternatives
Requires(postun): update-alternatives
Suggests:       osc
Conflicts:      %{oldpython}-bugzillatools
BuildArch:      noarch
%python_subpackages

%description
This is a Python module that provides a Python-ish interface to
Bugzilla over XMLRPC. It supports the Web Services provided by
upstream Bugzilla 3.0 and 3.2.

It also includes a 'bugzilla' commandline client which can be used for quick,
ad-hoc bugzilla jiggery-pokery.

%prep
%setup -q
%patch0 -p1
sed -i -e '1{/^#!\/usr\/bin\/env python/d}' bugzilla/_cli.py

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/bugzilla
%python_clone -a %{buildroot}%{_mandir}/man1/bugzilla.1
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%{python_install_alternative bugzilla bugzilla.1}

%postun
%python_uninstall_alternative bugzilla

%check
%python_expand py.test-%{$python_version}

%files %{python_files}
%defattr(-,root,root,-)
%python_alternative %{_bindir}/bugzilla
%python_alternative %{_mandir}/man1/bugzilla.1%{ext_man}
%{python_sitelib}/bugzilla
%{python_sitelib}/python_bugzilla-%{version}-py*.egg-info

%changelog
* Tue Oct 26 2021 Julio González Gil <jgonzalez@suse.com>
- Fix HTTP Basic authentication for python3 (bsc#1098219)
- Modified:
  * 106-basic-auth.diff
* Wed Oct 16 2019 Julio González Gil <jgonzalez@suse.com>
- Backport from upstream: HTTP Basic authentication feature (as used
  by SUSE and openSUSE) (bsc#1098219)
- Add:
  * 106-basic-auth.diff
* Sun Sep 15 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v2.3.0
  * restrict-login support
  * cli: Add support for private attachments
  * Fix python3 deprecation warnings
  * Drop python 3.3 support, minimum python3 is python 3.4 now
* Thu Aug 16 2018 mcepl@suse.com
- Update to 2.2.0:
  - Port tests to pytest
  - cli: --cert Client side certificate support (Tobias Wolter)
  - cli: add ability to post comment while sending attachment (Jeff Mahoney)
  - cli: Add --comment-tag option
  - cli: Add info --active-components
  - Add a raw Product.get wrapper API
* Mon May  7 2018 dimstar@opensuse.org
- Fix conflict for python-bugzillatools: we have to take extra care
  for the single-spec rewritter not to conflict with
  python2-bugzillatools in the end (which does not exist).
* Wed May  2 2018 tbechtold@suse.com
- Add Conflicts for python-bugzillatools
* Mon Apr 30 2018 jengelh@inai.de
- Trim history lesson and rhetoric wording from %%description.
* Wed Apr 25 2018 tbechtold@suse.com
- convert to singlespec
- use pypi as source
- update url
* Wed Apr 25 2018 tbechtold@suse.com
- update to 2.1.0:
  - Support for bugzilla 5 API Keys (Dustin J. Mitchell)
  - bugzillarc can be used to set default URL for the cli tool
  - Revive update_flags wrapper
  - Bug fixes and minor improvements
  - Several fixes for use with bugzilla 5
  - Bugzilla.bug_autorefresh now defaults to False
  - Credentials are now cached in ~/.cache/python-bugzilla/
  - bin/bugzilla was converted to argparse
  - bugzilla query --boolean_chart option is removed
  - Unify command line flags across sub commands
- drop NovellBugzilla.patch (no longer needed)
* Thu Jul 14 2016 jsegitz@novell.com
- Update to version 1.2.2
- Added NovellBugzilla.patch to ensure it works with SUSE internal
  bugzilla.
* Tue Sep 23 2014 bwiedemann@suse.com
- update nvlbugzilla.py to reflect that server now has ver 4.4
* Thu Jun 27 2013 jmatejek@suse.com
- update to 0.9.0
  * CVE-2013-2191: Switch to pycurl to get SSL host and cert validation
    (fixes bnc#825876)
  * bugzilla: modify: add --dependson (Don Zickus)
  * bugzilla: new: add --groups option (Paul Frields)
  * bugzilla: modify: Allow setting nearly every bug parameter
- update to suse3 from gitorious
  * remerged NovellBugzilla functionality
    (upstream inclusion pending bnc#822053)
* Fri May 24 2013 jmatejek@suse.com
- update to 0.8.0
  * support for Bugzilla 4 and above
  * streamlined internals
- update to suse2 from gitorious
  * include all suse patches
  * use osc's methods to parse .oscrc
* Wed May 22 2013 speilicke@suse.com
- Apply python-bugzilla-0.6.2-section.patch
- Cleanup spec file
- Package README
* Thu May 16 2013 werner@suse.de
- Fix UL sections that is check also for URL without final slash
  this may fix bnc#807901
* Thu Jan  3 2013 toddrme2178@gmail.com
- Fix building on SLES 11
* Tue Jan 31 2012 jmatejek@suse.com
- remove basic auth credentials from backtraces
- Novell Bugzilla is the default when using bugzilla command line tool
* Fri Jan 27 2012 jmatejek@suse.com
- update to openSUSE-1 tag from openSUSE's git branch
  * better handling of NovellBugzilla instances
  * using HTTP basic auth instead of IChain
* Fri Jul 29 2011 mvyskocil@suse.cz
- update to 0.6.2, rebased all patches
  * backport --outputformat feature from git
* Fri Jul 29 2011 mvyskocil@suse.cz
- add 0005-Add-Bugzilla34._query.patch fixing query command
- add 0020-allow-various-bnc-instances-in-NovellBugzilla.patch
* Mon May 23 2011 mvyskocil@suse.cz
- update to 0.6.1
  * many new parameters for bugzilla command-line tool like --target_milestone,
  - -private, --status, --assignee, et all
  * add support for Bugzilla 36
  * Unicode related fixes
- SUSE specific fixes
  * novell bugzilla support in getBugzillaClassForURL
  * obfuscated password support in oscrc
  * move novell bugzilla to 3.4
  * xmlrpclib changes done in python 2.7 from master [bug#685842]
- create suse branch for stashing SUSE specific changes
  https://gitorious.org/opensuse/python-bugzilla/commits/suse
* Thu Jun 17 2010 matejcik@suse.cz
- recognize Novell bugzilla in default constructor
* Wed Aug 26 2009 mvyskocil@suse.cz
- Added a patch with support of obfuscated passwords introduced in osc-0.121
* Wed Jul 22 2009 mvyskocil@suse.cz
- Initial packaging of python-bugzilla 0.5 with Novell Bugzilla patches
